@@ -1,6 +1,6 @@
 import requests
 from urllib.parse import urlencode
-from exceptions import InstagramException
+from .exceptions import InstagramException
 
 
 class API:
@@ -67,11 +67,3 @@ class API:
             raise InstagramException(response.status_code, response.json())
 
         return response.json()
-
-
-client = API('6c82fe30cb1942eda9df91748517283c', '39bbb118a37a4682b44bc0348ffee6bc')
-# print(client.get_authorization_url('http://127.0.0.1:8080/source/connect/instagram'))
-# print(client.get_access_token('332bdc8406114becad5912a3c9c31fba', 'http://127.0.0.1:8080/source/connect/instagram'))
-client.set_access_token('2281645626.6c82fe3.315802b5935f4585bc2eb8304d04c978')
-response = client.get('users/338299268', q='ajmeraharsh')
-print(response)
